@@ -5,6 +5,7 @@ from marshmallow import (
     pre_load,
     ValidationError,
 )
+from ...utils.utils import pre_load_date_fields
 
 
 class DealResourceSchema(Schema):
@@ -33,3 +34,13 @@ class DealResourceSchema(Schema):
             if in_data['company_ous_id'] is not None:
                 result += 1
         return result
+
+    def convert_string_to_datetime(self, in_data):
+        date_fields = ['announcement_date']
+
+        in_data = pre_load_date_fields(
+            in_data,
+            date_fields,
+            date_format='%Y%m%dT%H%M%S',
+        )
+        return in_data
