@@ -12,5 +12,7 @@ class InterventionConditionResourceSchema(Schema):
     intervention_id = fields.Integer(required=True)
     condition_id = fields.Integer(required=True)
     stage = fields.Integer(allow_none=True)
+    geography = fields.String(allow_none=True)
+    line = fields.Integer(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
     updated_at = fields.DateTime()
