@@ -10,5 +10,5 @@ class InterventionNewswireResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     news_id = fields.Integer(required=True)
-    norm_cui = fields.String(validate=not_blank, required=True, index=True)
+    intervention_id = fields.Integer(required=True)
     updated_at = fields.DateTime()
