@@ -14,10 +14,12 @@ class NCTStudyResourceSchema(Schema):
     nct_id = fields.String(allow_none=False, validate=not_blank)
     brief_title = fields.String(allow_none=True)
     study_status = fields.String(allow_none=True)
+    study_type = fields.String(allow_none=True)
     study_start_date = fields.DateTime(allow_none=True)
     last_update_submitted_qc_date = fields.DateTime(allow_none=True)
     phase = fields.String(allow_none=True)
     sponsors = fields.String(allow_none=True)
+    conditions = fields.String(allow_none=True)
     industry_flag = fields.Boolean()
     updated_at = fields.DateTime(dump_only=True)
 
